# coding: utf-8

""" A Python tool for interacting with NASA's ADS system. """

__author__ = "Andy Casey <andy@astrowizici.st>"
__version__ = "0.0.796"

from core import search, metrics, metadata, retrieve_article
